@@ -6,7 +6,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
   'Dist::Zilla::Role::PluginBundle::PluginRemover';
 use namespace::clean;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 # Revisions can include entries with the standard plugin name, array ref of plugin/name/config,
 # or coderefs which are passed the pluginbundle object and return one of these formats.
@@ -80,6 +80,8 @@ Dist::Zilla::PluginBundle::Starter - A minimal Dist::Zilla plugin bundle
   
   [@Starter]           ; all that is needed to start
   revision = 1         ; always defaults to revision 1
+  
+  ; configuring examples
   -remove = GatherDir  ; to use [Git::GatherDir] instead, for example
   ExecDir.dir = script ; change the directory used by [ExecDir]
 
@@ -90,7 +92,9 @@ minimal amount of work to release a complete distribution reliably. It is
 similar in purpose to L<[@Basic]|Dist::Zilla::PluginBundle::Basic>, but with
 additional features to stay up to date and allow greater customization. The
 selection of included plugins is intended to be unopinionated and unobtrusive,
-so that it is usable for any well-formed CPAN distribution.
+so that it is usable for any well-formed CPAN distribution. If you're just
+getting started with L<Dist::Zilla>, check out the tutorials at
+L<http://dzil.org>.
 
 C<[@Starter]> composes the L<PluginRemover|Dist::Zilla::Role::PluginBundle::PluginRemover>
 and L<Config::Slicer|Dist::Zilla::Role::PluginBundle::Config::Slicer> roles to
@@ -109,8 +113,9 @@ uploading to CPAN.
 
 Migrating from C<[@Basic]> is easy for most cases. Most of the bundle is the
 same, so just make sure to remove any extra plugins that C<[@Starter]> already
-includes. Migrating a more complex set of plugins, including some that interact
-with the additional generated files, may require more careful consideration.
+includes, and configure the included plugins if needed (see L</"CONFIGURING">).
+Migrating a more complex set of plugins, including some that interact with the
+additional generated files, may require more careful consideration.
 
 For one-line initialization of a new C<[@Starter]>-based distribution, try
 L<Dist::Zilla::MintingProfile::Starter>.
@@ -195,13 +200,13 @@ L<[Test::Compile]|Dist::Zilla::Plugin::Test::Compile>.
 
 By using the L<PluginRemover|Dist::Zilla::Role::PluginBundle::PluginRemover> or
 L<Config::Slicer|Dist::Zilla::Role::PluginBundle::Config::Slicer> role options,
-you can customize the C<[@Starter]> bundle's included plugins as desired. Here
+the C<[@Starter]> bundle's included plugins can be customized as desired. Here
 are some examples:
 
 =head2 GatherDir
 
-If you are using git source control, you may wish to replace the default
-L<[GatherDir]|Dist::Zilla::Plugin::GatherDir> plugin with
+If the distribution is using git source control, it is often helpful to replace
+the default L<[GatherDir]|Dist::Zilla::Plugin::GatherDir> plugin with
 L<[Git::GatherDir]|Dist::Zilla::Plugin::Git::GatherDir>.
 
   [Git::GatherDir]
@@ -213,8 +218,8 @@ L<[Git::GatherDir]|Dist::Zilla::Plugin::Git::GatherDir>.
 The L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod> plugin
 generates a plaintext README from the POD text in the distribution's
 L<Dist::Zilla/"main_module"> by default, but can be configured to look
-elsewhere. The standard README should always be plaintext, but if you want to
-generate a non-plaintext README in addition, you can simply use the plugin a
+elsewhere. The standard README should always be plaintext, but in order to
+generate a non-plaintext README in addition, the plugin can simply be used a
 second time. Note that POD-format READMEs should not be included in the
 distribution build because they will get indexed and installed due to an oddity
 in CPAN installation tools.
@@ -240,20 +245,40 @@ L<[ExecDir]|Dist::Zilla::Plugin::ExecDir> default) for executable scripts.
 
 =head2 MetaNoIndex
 
-You may wish to specify that additional files or directories are not indexed as
-CPAN modules. (See L<Config::MVP::Slicer/"CONFIGURATION SYNTAX"> for an
-explanation of the subscripts for slicing array attributes.)
+The distribution may include additional files or directories that should not
+have their contents indexed as CPAN modules. (See
+L<Config::MVP::Slicer/"CONFIGURATION SYNTAX"> for an explanation of the
+subscripts for slicing array attributes.)
 
   [@Starter]
   MetaNoIndex.file[0] = eggs/FooBar.pm
   MetaNoIndex.directory[a] = eggs
   MetaNoIndex.directory[b] = bacon
 
+=head2 MetaProvides
+
+The L<[MetaProvides::Package]|Dist::Zilla::Plugin::MetaProvides::Package>
+plugin will use the distribution's version (as set in C<dist.ini> or by a
+plugin) as the version of each module when populating the C<provides> metadata
+by default. If the distribution does not have uniform module versions, the
+plugin can be configured to use each module's hardcoded version.
+
+  [@Starter]
+  MetaProvides::Package.inherit_version = 0
+
+With this option set, it will use the main distribution version as a fallback
+for any module where a version is not found. This can also be overridden, so
+that no version will be specified for these modules in the metadata.
+
+  [@Starter]
+  MetaProvides::Package.inherit_version = 0
+  MetaProvides::Package.inherit_missing = 0
+
 =head1 EXTENDING
 
 This bundle includes a basic set of plugins for releasing a distribution, but
 there are many more common non-intrusive tasks that L<Dist::Zilla> can help
-with simply by using additional plugins in your C<dist.ini>.
+with simply by using additional plugins in the C<dist.ini>.
 
 =head2 Name
 
@@ -268,13 +293,15 @@ L<[LicenseFromModule]|Dist::Zilla::Plugin::LicenseFromModule>.
 
 =head2 Versions
 
-To automatically extract the distribution's version from the main module and
-bump it after a release, you can use either
+A common approach to maintaining versions in L<Dist::Zilla>-managed
+distributions is to automatically extract the distribution's version from the
+main module, maintain uniform module versions, and bump the version after a
+release. This can be accomplished with either
 L<[RewriteVersion]|Dist::Zilla::Plugin::RewriteVersion> with
 L<[BumpVersionAfterRelease]|Dist::Zilla::Plugin::BumpVersionAfterRelease>, or
 L<[VersionFromModule]|Dist::Zilla::Plugin::VersionFromModule> with
 L<[ReversionOnRelease]|Dist::Zilla::Plugin::ReversionOnRelease>. Don't mix
-these two approaches!
+these two methods!
 
 =head2 Changelog
 
@@ -297,7 +324,7 @@ manually, use L<[MetaResources]|Dist::Zilla::Plugin::MetaResources>.
 
 =head2 Prereqs
 
-To automatically set distribution prereqs from a cpanfile, use
+To automatically set distribution prereqs from a L<cpanfile>, use
 L<[Prereqs::FromCPANfile]|Dist::Zilla::Plugin::Prereqs::FromCPANfile>. To
 specify prereqs manually, use L<[Prereqs]|Dist::Zilla::Plugin::Prereqs>.
 
